@@ -9,7 +9,7 @@ from shapely.ops import nearest_points
 
 from abc import ABC as abstract_base
 
-import oogeo
+import src.oogeo
 from src.oogeo.objects.geometrybase import GeometryBase
 from src.oogeo.functions.constants import BUFFER_END_STYLES, BUFFER_JOIN_STYLES
 from src.oogeo.functions.conversions import string_to_units
@@ -61,9 +61,9 @@ def get_near_points(target_geometry, near_geometry, tolerance):
             continue
 
         # if we found a near edge do an out-front test
-        nearest_point = edge.nearest_point(point) if isinstance(edge, oogeo.objects.line.Line) else edge
+        nearest_point = edge.nearest_point(point) if isinstance(edge, src.oogeo.objects.line.Line) else edge
         if not nearest_point.equals(point):
-            test_line = oogeo.objects.line.Line([point, nearest_point], point.spatial_reference)
+            test_line = src.oogeo.objects.line.Line([point, nearest_point], point.spatial_reference)
             if not test_line.is_perpendicular(edge, tolerance=3):
                 continue
             crosses_other_edge = False
@@ -94,14 +94,14 @@ def get_near_points(target_geometry, near_geometry, tolerance):
             # and out-front test on the test point - if its not out front don't consider it
             test_nearest_point = edge.nearest_point(test_point)
             if not test_point.equals(test_nearest_point):
-                test_line = oogeo.objects.line.Line([test_point, test_nearest_point], point.spatial_reference)
+                test_line = src.oogeo.objects.line.Line([test_point, test_nearest_point], point.spatial_reference)
                 if not test_line.is_perpendicular(edge, tolerance=3):
                     continue
 
             # if the test point is closer and out front, see if the line formed between the
             # two points are perpendicular to the edge - if so we want to ignore this
             # point for analysis
-            test_line = oogeo.objects.line.Line([test_point, point], point.spatial_reference)
+            test_line = src.oogeo.objects.line.Line([test_point, point], point.spatial_reference)
             if test_line.is_perpendicular(edge):
                 analyze = False
 
@@ -212,15 +212,15 @@ class MultipointBase(GeometryBase, abstract_base):
             else intersection_geometries
         for geometry in intersection_geometries:
             if isinstance(geometry, ShapelyPoint):
-                return_geometries.append(oogeo.objects.point.Point(geometry, self.spatial_reference, allow_invalid=allow_invalid))
+                return_geometries.append(src.oogeo.objects.point.Point(geometry, self.spatial_reference, allow_invalid=allow_invalid))
             elif (isinstance(geometry, LineString) or isinstance(geometry, MultiLineString)) and not geometry.is_empty:
-                return_geometries.append(oogeo.objects.line.Line(geometry, self.spatial_reference, allow_invalid=allow_invalid))
+                return_geometries.append(src.oogeo.objects.line.Line(geometry, self.spatial_reference, allow_invalid=allow_invalid))
             elif isinstance(geometry, ShapelyPolygon) or isinstance(geometry, MultiPolygon):
                 if geometry:
-                    return_geometries.append(oogeo.objects.polygon.Polygon(geometry, self.spatial_reference, allow_invalid=allow_invalid))
+                    return_geometries.append(src.oogeo.objects.polygon.Polygon(geometry, self.spatial_reference, allow_invalid=allow_invalid))
             elif isinstance(geometry, MultiPoint):
                 for point in geometry.geoms:
-                    return_geometries.append(oogeo.objects.point.Point(point, self.spatial_reference, allow_invalid=allow_invalid))
+                    return_geometries.append(src.oogeo.objects.point.Point(point, self.spatial_reference, allow_invalid=allow_invalid))
 
         if len(return_geometries) == 0:
             return None
@@ -246,9 +246,9 @@ class MultipointBase(GeometryBase, abstract_base):
             distance = string_to_units(distance, 'FEET')
 
         if distance == 0:
-            return oogeo.objects.polygon.Polygon(self.geometry.buffer(distance), self.spatial_reference, allow_invalid=allow_invalid)
+            return src.oogeo.objects.polygon.Polygon(self.geometry.buffer(distance), self.spatial_reference, allow_invalid=allow_invalid)
 
-        buffer_polygon = oogeo.objects.polygon.Polygon(
+        buffer_polygon = src.oogeo.objects.polygon.Polygon(
             self.geometry.buffer(distance,
                 resolution=100,
                 cap_style=BUFFER_END_STYLES[end_style],
@@ -288,7 +288,7 @@ class MultipointBase(GeometryBase, abstract_base):
             that is nearest to the specified point.
         """
         nearest_point = nearest_points(self.geometry, point.geometry)[0]
-        return oogeo.objects.point.Point(nearest_point, self.spatial_reference)
+        return src.oogeo.objects.point.Point(nearest_point, self.spatial_reference)
 
     def nearest_vertex(self, point):
         """ Returns the vertex nearest to the specified point.
@@ -311,7 +311,7 @@ class MultipointBase(GeometryBase, abstract_base):
         :param other_geometry: The geometry to be tested.
         :return: True if the polygon contains the other geometry, otherwise False.
         """
-        if exact or isinstance(other_geometry, oogeo.objects.point.Point):
+        if exact or isinstance(other_geometry, src.oogeo.objects.point.Point):
            return self.geometry.contains(other_geometry.geometry)
 
         if self.geometry.contains(other_geometry.geometry):
@@ -363,7 +363,7 @@ class MultipointBase(GeometryBase, abstract_base):
         """
         new_geometry = self.clone()
         for point in self.points:
-            new_geometry = new_geometry.replace_point(point, oogeo.objects.point.Point({'x': point.x * scale_factor, 'y': point.y * scale_factor}, self.spatial_reference), self.allow_invalid)
+            new_geometry = new_geometry.replace_point(point, src.oogeo.objects.point.Point({'x': point.x * scale_factor, 'y': point.y * scale_factor}, self.spatial_reference), self.allow_invalid)
         return new_geometry
 
     def transform(self, delta_x, delta_y):
@@ -378,7 +378,7 @@ class MultipointBase(GeometryBase, abstract_base):
         """
         new_geometry = self.clone()
         for point in self.points:
-            new_geometry = new_geometry.replace_point(point, oogeo.objects.point.Point({'x': point.x + delta_x, 'y': point.y + delta_y}, self.spatial_reference), allow_invalid=True)
+            new_geometry = new_geometry.replace_point(point, src.oogeo.objects.point.Point({'x': point.x + delta_x, 'y': point.y + delta_y}, self.spatial_reference), allow_invalid=True)
         if self.allow_invalid or new_geometry.is_valid:
             return new_geometry
         raise ValueError('Invalid geometry detected: {}'.format(new_geometry.ewkt))
